betty.test_utils.ancestry.event_type module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.test_utils.ancestry.event_type module

Test utilities for `betty.ancestry.event_type`.

class betty.test_utils.ancestry.event_type.DummyEventType

  Bases: `DummyPlugin`, `EventType`

  A dummy event type implementation.

class betty.test_utils.ancestry.event_type.EventTypeTestBase

  Bases: `PluginTestBase`[`EventType`]

  A base class for testing `betty.ancestry.event_type.EventType` implementations.